#include <algorithm>
#include <climits>
#include <cstdio>
#include <fstream>
#include <iostream>
#include <map>
#include <set>
#include <sstream>
using namespace std;

const double padding = 10.0;
const bool auto_compress = true;

double global_y;
double tc_width, tc_height;


string svg_text(double x, double y, const string &txt) {
	stringstream ss;
	ss << "<text x='" << x << "'"
	   <<      " y='" << y << "'"
	   <<      " font-family='monospace'"
	   <<      " font-size='20'>"
	   << txt << "</text>" << endl;
	return ss.str();
}

string svg_rect(double x, double y, double w, double h, string style) {
	stringstream ss;
	ss << "<rect x='" << x << "' y='" << y << "'"
	   <<      " width='" << w << "' height='" << h << "'"
	   <<      " " << style + " />" << endl;
	return ss.str();
}

string svg_line(double x1, double y1, double x2, double y2, string style) {
	stringstream ss;
	ss << "<line x1='" << x1 << "' y1='" << y1 << "'"
	   <<      " x2='" << x2 << "' y2='" << y2 << "'"
	   <<      " " << style << " />" << endl;
	return ss.str();
}

void process_tc(string &name, istream &input, ostream &output) {
	int P;
	input >> P;
	vector<vector<int>> x (P), y (P);
	set<int> seen_x, seen_y;

	// READ TESTCASE
	for (int p = 0; p < P; p++) {
		int N;
		input >> N;
		x[p].resize(N);
		y[p].resize(N);
		for (int i = 0; i < N; i++) {
			input >> x[p][i] >> y[p][i];
			seen_x.insert(x[p][i]);
			seen_y.insert(y[p][i]);
		}
	}

	double left = *seen_x.begin(), right = *seen_x.rbegin();
	double top = *seen_y.begin(), bottom = *seen_y.rbegin();
	double width  = (right - left);
	double height = (bottom - top);

	if (auto_compress && (width > (tc_width / 4) || height > (tc_height / 4))) {
		name += " (auto-compressed coords)";
		int xval = 0, yval = 0;
		int lastx = INT_MIN, lasty = INT_MIN;
		map<int,int> new_x, new_y;
		for (int tx : seen_x) {
			xval += (tx - lastx > 1) ? 3 : 1;
			new_x[tx] = xval;
			lastx = tx;
		}
		for (int ty : seen_y) {
			yval += (ty - lasty > 1) ? 3 : 1;
			new_y[ty] = yval;
			lasty = ty;
		}

		seen_x.clear(); seen_y.clear();
		for (int p = 0; p < P; p++) {
			for (size_t i = 0; i < x[p].size(); i++) {
				x[p][i] = new_x[ x[p][i] ];
				y[p][i] = new_y[ y[p][i] ];
				seen_x.insert(x[p][i]);
				seen_y.insert(y[p][i]);
			}
		}
		left = *seen_x.begin(), right = *seen_x.rbegin();
		top = *seen_y.begin(), bottom = *seen_y.rbegin();
		width  = (right - left);
		height = (bottom - top);
	}

	double dx = 0, dy = 0;

	double scale = min((tc_width - 10) / width, (tc_height - 10) / height);
	width *= scale;
	height *= scale;
	dx = (tc_width - width) / 2;
	dy = (tc_height - height) / 2;


	dx = padding  + dx;
	dy = global_y + dy;

	output << string(4, ' ');
	output << svg_rect(padding, global_y, tc_width, tc_height,
	                   "fill='#CCCCCC' stroke='#400040'");

	auto xtr = [&](double x) { return dx + (x - left) * scale; };
	auto ytr = [&](double y) { return dy + (y - top ) * scale; };

	output << string(4, ' ');
	output << svg_rect(xtr(left) - 5,              ytr(top) - 5,
	                   xtr(right) - xtr(left) + 10, ytr(bottom) - ytr(top) + 10,
	                   "fill='#FFFFFF' stroke='none'");

	vector<string> polycolor {
		"#0000FF",
		"#00FF00",
		"#FF00FF",
	};

	for (int p = 0; p < P; p++) {
		string color = polycolor[p % polycolor.size()];
		for (size_t i = 1; i < x[p].size(); i++) {
			output << string(8, ' ');
			output << svg_line(xtr(x[p][i-1]), ytr(y[p][i-1]),
			                   xtr(x[p][i]),   ytr(y[p][i]),
			                   "stroke='" + color + "'");
		}
	}



	global_y += tc_height;


	global_y += 20;
}

void process_file(const string &filename, istream &input, ostream &output) {
	int TC;
	input >> TC;

	string solname = filename;
	if (solname.size() > 3 && solname.substr(solname.size() - 3) == ".in")
		solname = solname.substr(0, solname.size() - 3);
	solname += ".out";
	ifstream sol (solname);

	for (int tc = 1; tc <= TC; tc++) {
		string tc_name = filename + ", TC " + to_string(tc);

		global_y += 20;
		double textpos = global_y;
		global_y += 5;

		stringstream output2;
		process_tc(tc_name, input, output2);

		string solution;
		if (getline(sol, solution).fail())
			solution = "ERROR reading solution";

		output << svg_text(padding, textpos, tc_name + " (" + solution + ")");
		output << output2.rdbuf();
	}
}

int main(int argc, char **argv) {
	vector<string> args;
	args.reserve(argc);
	for (int i = 0; i < argc; i++) {
		args.emplace_back(argv[i]);
	}

	try {
		tc_width = stod(args.at(1));
		tc_height = stod(args.at(2));
		args.at(3);
	} catch(...) {
		cerr << "usage: " << args[0] << " [tc_width] [tc_height] [input-file] [...] > output.svg" << endl;
		return 1;
	}

	if (min(tc_width, tc_height) < 10 || max(tc_width, tc_height) > 10000) {
		cerr << "please pick sane values for tc_width and tc_height" << endl;
		cerr << "(>= 10 and <= 10000, e.g. 1280 720)" << endl;
		return 1;
	}

	args.erase(args.begin(), args.begin() + 3); 


	global_y = padding;
	
	stringstream output;
	for (string fn : args) {
		ifstream input (fn);
		process_file(fn, input, output);
	}

	cout << "<svg xmlns='http://www.w3.org/2000/svg' version='1.1' "
	         << " width='" << 2 * padding + tc_width << "' "
	         << " height='" << global_y + padding << "'>" << endl;
	cout << output.str();
	cout << "</svg>" << endl;
}
